@@ -19,6 +19,7 @@
 import sys
 from collections import Iterable
 
+
 if sys.version_info[0] == 3:
     base = (str, bytes)
     coerce = str
@@ -41,6 +42,12 @@ def to_str(string):
     return string
 
 
+def to_unicode(string):
+    if not isinstance(string, coerce):
+        return string.decode('utf-8')
+    return string
+
+
 def u(s):
     if sys.version_info[0] == 2:
         return s.decode('utf-8')
