@@ -22,7 +22,7 @@ Value adapters to use when a chart doesn't accept all value types
 """
 import datetime
 from numbers import Number
-from pygal.i18n import COUNTRIES
+from decimal import Decimal
 
 
 def positive(x):
@@ -52,3 +52,9 @@ def date(x):
         except OverflowError:
             return None
     return x
+
+
+def decimal_to_float(x):
+    if isinstance(x, Decimal):
+        return float(x)
+    return x
