@@ -221,6 +221,9 @@ class Config(CommonConfig):
     legend_at_bottom = Key(
         False, bool, "Look", "Set to true to position legend at bottom")
 
+    legend_at_bottom_columns = Key(
+        None, int, "Look", "Set to true to position legend at bottom")
+
     legend_box_size = Key(
         12, int, "Look", "Size of legend boxes")
 
@@ -303,6 +306,10 @@ class Config(CommonConfig):
         "%Y-%m-%d %H:%M:%S.%f", str, "Label",
         "Date format for strftime to display the DateY X labels")
 
+    missing_value_fill_truncation = Key(
+        "x", str, "Look",
+        "Filled series with missing x and/or y values at the end of a series are closed at the first value with a missing 'x' (default), 'y' or 'either'")
+
     # Value #
     human_readable = Key(
         False, bool, "Value", "Display values in human readable format",
@@ -382,8 +389,8 @@ class Config(CommonConfig):
 
     # Misc #
     js = Key(
-        ('http://kozea.github.com/pygal.js/javascripts/svg.jquery.js',
-         'http://kozea.github.com/pygal.js/javascripts/pygal-tooltips.js'),
+        ('http://kozea.github.io/pygal.js/javascripts/svg.jquery.js',
+         'http://kozea.github.io/pygal.js/javascripts/pygal-tooltips.js'),
         list, "Misc", "List of js file",
         "It can be a filepath or an external link",
         str)
