@@ -154,7 +154,8 @@ class Graph(BaseGraph):
             self.svg.node(
                 guides, 'path',
                 d='M%f %f v%f' % (x or 0, 0, self.view.height),
-                class_='%s%sline' % (
+                class_='%s%s%sline' % (
+                    'axis ' if label == "0" else '',
                     'major ' if major else '',
                     'guide ' if position != 0 and not last_guide else ''))
             y += .5 * self.label_font_size + 5
@@ -229,7 +230,8 @@ class Graph(BaseGraph):
                 self.svg.node(
                     guides, 'path',
                     d='M%f %f h%f' % (0, y, self.view.width),
-                    class_='%s%sline' % (
+                    class_='%s%s%sline' % (
+                        'axis ' if label == "0" else '',
                         'major ' if major else '',
                         'guide ' if position != 0 else ''))
             text = self.svg.node(
@@ -279,7 +281,8 @@ class Graph(BaseGraph):
             y = (self.margin.top + self.view.height +
                  self._x_title_height +
                  self._x_labels_height + self.spacing)
-            cols = ceil(sqrt(self._order)) or 1
+            cols = self.legend_at_bottom_columns or ceil(
+                sqrt(self._order)) or 1
 
             if not truncation:
                 available_space = self.view.width / cols - (
@@ -418,6 +421,11 @@ class Graph(BaseGraph):
             x, y, self.interpolation_precision,
             **self.interpolation_parameters))
 
+    def _rescale(self, points):
+        return [
+            (x, self._scale_diff + (y - self._scale_min_2nd) * self._scale)
+            for x, y in points if y is not None]
+
     def _tooltip_data(self, node, value, x, y, classes=None):
         self.svg.node(node, 'desc', class_="value").text = value
         if classes is None:
