@@ -27,7 +27,7 @@ from decimal import Decimal
 from math import floor, pi, log, log10, ceil
 from itertools import cycle
 from functools import reduce
-from pygal.adapters import not_zero, positive
+from pygal.adapters import not_zero, positive, decimal_to_float
 ORDERS = u("yzafpnµm kMGTPEZY")
 
 
@@ -38,6 +38,8 @@ def float_format(number):
 
 def humanize(number):
     """Format a number to engineer scale"""
+    if is_list_like(number):
+        return', '.join(map(humanize, number))
     order = number and int(floor(log(abs(number)) / log(1000)))
     human_readable = ORDERS.split(" ")[int(order > 0)]
     if order == 0 or order > len(human_readable):
@@ -344,6 +346,7 @@ def prepare_values(raw, config, cls, offset=0):
             if fun in adapters:
                 adapters.remove(fun)
         adapters = adapters + [positive, not_zero]
+    adapters = adapters + [decimal_to_float]
     adapter = reduce(compose, adapters) if not config.strict else ident
     series = []
 
